# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel
from .api_evaluation_run import APIEvaluationRun

__all__ = ["EvaluationRunRetrieveResponse"]


class EvaluationRunRetrieveResponse(BaseModel):
    evaluation_run: Optional[APIEvaluationRun] = None
