# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["KnowledgeBaseUpdateParams"]


class KnowledgeBaseUpdateParams(TypedDict, total=False):
    database_id: str
    """the id of the DigitalOcean database this knowledge base will use, optiona."""

    embedding_model_uuid: str
    """Identifier for the foundation model."""

    name: str

    project_id: str

    tags: List[str]
    """Tags to organize your knowledge base."""

    body_uuid: Annotated[str, PropertyInfo(alias="uuid")]
